@@ -4,7 +4,7 @@
 // C++ header
 // This file is part of rgl
 //
-// $Id: glgui.hpp 376 2005-08-03 23:58:47Z dadler $
+// $Id: glgui.hpp 545 2007-01-01 15:31:31Z dmurdoch $
 
 #include "opengl.hpp"
 
@@ -22,8 +22,8 @@ public:
     glListBase(listBase);
   };
 
-  void draw(char* text, int length, double adj);
-
+  void draw(char* text, int length, double adj, int gl2psActive);
+  
   GLuint listBase;
   GLuint firstGlyph;
   GLuint nglyph;
@@ -35,6 +35,13 @@ public:
 #define GL_BITMAP_FONT_LAST_GLYPH   127
 #define GL_BITMAP_FONT_COUNT       (GL_BITMAP_FONT_LAST_GLYPH-GL_BITMAP_FONT_FIRST_GLYPH+1)
 
+#define GL2PS_FONT 	"Helvetica"
+#define GL2PS_FONTSIZE 	12
+#define GL2PS_SCALING   0.8
+
+#define GL2PS_NONE	 0
+#define GL2PS_LEFT_ONLY	 1
+#define GL2PS_POSITIONAL 2
 
 #endif /* GL_GUI_H */
 
